function phi = orthopoly_evaluate_n(T, x)
%%  Evaluate nth orthogonal polynomial at x
%   Parameters
%     T: Tridiagonal matrix encoding the three term recurrence
%        size is (n+1)x(n+1)
%     x: evaluation points
%
%  Returns
%    phi: nth at x
%         normalized so that 0'th is 1 (w has unit weight)
%         Method: characteristic polynomial of n x n T
%                 with leading coefficient taken from the 
%                 product of the superdiagonal of the
%                 (n+1)x(n+1) T

n = size(T,1)-1;
%% compute the characteristic polynomial of T(1:n,1:n)
Lambda = eig(T(1:n, 1:n));
phi = 1 + 0 * x;
for i = 1:n,
      phi = phi.*(x - Lambda(i));
end
%%  normalization
if n > 0,
    phi = phi / prod(diag(T,1));
end
end